@@ -10,9 +10,8 @@ Built-in transports.
 """
 from __future__ import absolute_import
 
-import sys
-
 from kombu.syn import _detect_environment
+from kombu.utils import symbol_by_name
 
 
 def supports_librabbitmq():
@@ -77,20 +76,17 @@ _transport_cache = {}
 
 
 def resolve_transport(transport=None):
-    transport = TRANSPORT_ALIASES.get(transport, transport)
-    if callable(transport):
-        transport = transport()
-    transport_module_name, _, transport_cls_name = transport.rpartition('.')
-    if not transport_module_name:
-        raise KeyError('No such transport: %s' % (transport, ))
-    return transport_module_name, transport_cls_name
-
-
-def _get_transport_cls(transport=None):
-    transport_module_name, transport_cls_name = resolve_transport(transport)
-    __import__(transport_module_name)
-    transport_module = sys.modules[transport_module_name]
-    return getattr(transport_module, transport_cls_name)
+    if isinstance(transport, basestring):
+        try:
+            transport = TRANSPORT_ALIASES[transport]
+        except KeyError:
+            if '.' not in transport and ':' not in transport:
+                raise KeyError('No such transport: %s' % transport)
+        else:
+            if callable(transport):
+                transport = transport()
+        return symbol_by_name(transport)
+    return transport
 
 
 def get_transport_cls(transport=None):
@@ -105,5 +101,5 @@ def get_transport_cls(transport=None):
 
     """
     if transport not in _transport_cache:
-        _transport_cache[transport] = _get_transport_cls(transport)
+        _transport_cache[transport] = resolve_transport(transport)
     return _transport_cache[transport]
